# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401
from typing import List, Dict  # noqa: F401
from yk_utils.models import Model
from yk_utils.models import deserialization


class VerifyImagesRequest(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, probe_image: str=None, reference_image: str=None, matching_score_threshold: float=0.4):  # noqa: E501
        """VerifyImagesRequest - a model defined in Swagger

        :param probe_image: The probe_image of this VerifyImagesRequest.  # noqa: E501
        :type probe_image: str
        :param reference_image: The reference_image of this VerifyImagesRequest.  # noqa: E501
        :type reference_image: str
        :param matching_score_threshold: The matching_score_threshold of this VerifyImagesRequest.  # noqa: E501
        :type matching_score_threshold: float
        """
        self.swagger_types = {
            'probe_image': str,
            'reference_image': str,
            'matching_score_threshold': float
        }

        self.attribute_map = {
            'probe_image': 'probe_image',
            'reference_image': 'reference_image',
            'matching_score_threshold': 'matching_score_threshold'
        }

        self._probe_image = probe_image
        self._reference_image = reference_image
        self._matching_score_threshold = matching_score_threshold

    @classmethod
    def from_dict(cls, dikt) -> 'VerifyImagesRequest':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The verify_images_request of this VerifyImagesRequest.  # noqa: E501
        :rtype: VerifyImagesRequest
        """
        return deserialization.deserialize_model(dikt, cls)

    @property
    def probe_image(self) -> str:
        """Gets the probe_image of this VerifyImagesRequest.

        JPG base 64 string face image to be matched against reference image.  # noqa: E501

        :return: The probe_image of this VerifyImagesRequest.
        :rtype: str
        """
        return self._probe_image

    @probe_image.setter
    def probe_image(self, probe_image: str):
        """Sets the probe_image of this VerifyImagesRequest.

        JPG base 64 string face image to be matched against reference image.  # noqa: E501

        :param probe_image: The probe_image of this VerifyImagesRequest.
        :type probe_image: str
        """
        if probe_image is None:
            raise ValueError("Invalid value for `probe_image`, must not be `None`")  # noqa: E501

        self._probe_image = probe_image

    @property
    def reference_image(self) -> str:
        """Gets the reference_image of this VerifyImagesRequest.

        JPG base 64 string reference face image.  # noqa: E501

        :return: The reference_image of this VerifyImagesRequest.
        :rtype: str
        """
        return self._reference_image

    @reference_image.setter
    def reference_image(self, reference_image: str):
        """Sets the reference_image of this VerifyImagesRequest.

        JPG base 64 string reference face image.  # noqa: E501

        :param reference_image: The reference_image of this VerifyImagesRequest.
        :type reference_image: str
        """
        if reference_image is None:
            raise ValueError("Invalid value for `reference_image`, must not be `None`")  # noqa: E501

        self._reference_image = reference_image

    @property
    def matching_score_threshold(self) -> float:
        """Gets the matching_score_threshold of this VerifyImagesRequest.

        Matching score threshold used to verify matching between probe and reference image.  # noqa: E501

        :return: The matching_score_threshold of this VerifyImagesRequest.
        :rtype: float
        """
        return self._matching_score_threshold

    @matching_score_threshold.setter
    def matching_score_threshold(self, matching_score_threshold: float):
        """Sets the matching_score_threshold of this VerifyImagesRequest.

        Matching score threshold used to verify matching between probe and reference image.  # noqa: E501

        :param matching_score_threshold: The matching_score_threshold of this VerifyImagesRequest.
        :type matching_score_threshold: float
        """

        self._matching_score_threshold = matching_score_threshold



""" Module of the YooniK BiometricInThings API.
"""
from enum import Enum
from yk_utils.image import parse_image
from yk_utils.apis import request, YoonikApiException
from yk_bit.models import CaptureRequest, VerifyImagesRequest, VerifyRequest, \
    CaptureResponse, VerifyResponse, VerifyImagesResponse


class BiTStatus(Enum):
    NotAvailable = 0
    Available = 1


def capture(capture_timeout: float = 10, anti_spoofing: bool = True,
            live_quality_analysis: bool = False) -> CaptureResponse:
    """ Provides a live captured frame from the devices camera in base 64 format and its quality metrics.
    :param capture_timeout:
        Capture timeout in seconds.
    :param anti_spoofing:
        Activates anti-spoofing detection.
    :param live_quality_analysis:
        Activate ISO/ICAO-19794-5 face quality compliance checks on the live face images.
    :return:
        The captured image in base 64 format and the capture status.
    """

    url = 'bit/capture'
    capture_request = CaptureRequest(capture_timeout, anti_spoofing, live_quality_analysis).to_dict()
    response = request('POST', url, json=capture_request)

    return CaptureResponse.from_dict(response)


def verify(reference_image, capture_time_out: float = 10.0, matching_score_threshold: float = 0.4,
           anti_spoofing: bool = True, live_quality_analysis: bool = False,
           reference_quality_analysis: bool = False) -> VerifyResponse:
    """ Captures a live frame from the camera and cross examines with the reference image.
        :param reference_image:
            Image can be a string, a file path or a file-like object.
        :param reference_quality_analysis:
            Activate ISO/ICAO-19794-5 face quality compliance checks on the image.
        :param live_quality_analysis:
            Activate ISO/ICAO-19794-5 face quality compliance checks on the live face images.
        :param anti_spoofing:
            Activate anti-spoofing detection.
        :param matching_score_threshold:
            Defines the minimum acceptable score for a positive match.
        :param capture_time_out:
            Capture timeout in seconds.
        :return:
            The frame that was captured to verify against the reference in base 64 format,
             its verification status and the matching score.
        """
    url = 'bit/verify'
    verify_request = VerifyRequest(
        reference_image=parse_image(reference_image),
        capture_time_out=capture_time_out,
        matching_score_threshold=matching_score_threshold,
        anti_spoofing=anti_spoofing,
        live_quality_analysis=live_quality_analysis,
        reference_quality_analysis=reference_quality_analysis,
    ).to_dict()

    response = request('POST', url, json=verify_request)

    return VerifyResponse.from_dict(response)


def verify_images(probe_image, reference_image, matching_score_threshold: float = 0.4) \
        -> VerifyImagesResponse:
    """ Performs face matching between the two provided images.
    :param matching_score_threshold:
        Defines the minimum acceptable score for a positive match.
    :param probe_image:
        Image can be a string or a file path or a file-like object.
    :param reference_image:
        Image can be a string or a file path or a file-like object.
    :return:
        The matching score and the verified images status.
    """
    url = 'bit/verify_images'
    verify_images_request = VerifyImagesRequest(
        probe_image=parse_image(probe_image),
        reference_image=parse_image(reference_image),
        matching_score_threshold=matching_score_threshold
    ).to_dict()

    response = request('POST', url, json=verify_images_request)

    return VerifyImagesResponse.from_dict(response)


def status() -> BiTStatus:
    """ Checks for the camera status. """
    url = 'bit/status'
    # If the camera is available the request is answered with an empty 200 OK. Otherwise exception is thrown.
    try:
        request('GET', url)
    except YoonikApiException as bit_exception:
        if bit_exception.status_code == 503:
            return BiTStatus.NotAvailable
        raise
    return BiTStatus.Available


def setup():
    """
        Perform BiT setup actions
    """
    url = 'bit/setup'
    request('GET', url)




# coding: utf-8

# flake8: noqa
"""
    YooniK.Bit API

    Functionalities to control biometric capture or verification of the YooniK.BiT.  # noqa: E501

    OpenAPI spec version: 1.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from yk_bit.models.capture_request import CaptureRequest
from yk_bit.models.capture_response import CaptureResponse
from yk_bit.models.verify_request import VerifyRequest
from yk_bit.models.verify_response import VerifyResponse
from yk_bit.models.verify_images_request import VerifyImagesRequest
from yk_bit.models.verify_images_response import VerifyImagesResponse



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401
from typing import List, Dict  # noqa: F401

from yk_utils.models import deserialization
from yk_utils.models import Model


class CaptureResponse(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, image: str=None, capture_status: List[str]=None):  # noqa: E501
        """CaptureResponse - a model defined in Swagger

        :param image: The image of this CaptureResponse.  # noqa: E501
        :type image: str
        :param capture_status: The capture_status of this CaptureResponse.  # noqa: E501
        :type capture_status: List[str]
        """
        self.swagger_types = {
            'image': str,
            'capture_status': List[str]
        }

        self.attribute_map = {
            'image': 'image',
            'capture_status': 'capture_status'
        }

        self._image = image
        self._capture_status = capture_status

    @classmethod
    def from_dict(cls, dikt) -> 'CaptureResponse':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The capture_response of this CaptureResponse.  # noqa: E501
        :rtype: CaptureResponse
        """
        return deserialization.deserialize_model(dikt, cls)

    @property
    def image(self) -> str:
        """Gets the image of this CaptureResponse.

        JPG Base 64 string face crop according to ISO/ICAO 19794-5 Token.  # noqa: E501

        :return: The image of this CaptureResponse.
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image: str):
        """Sets the image of this CaptureResponse.

        JPG Base 64 string face crop according to ISO/ICAO 19794-5 Token.  # noqa: E501

        :param image: The image of this CaptureResponse.
        :type image: str
        """

        self._image = image

    @property
    def capture_status(self) -> List[str]:
        """Gets the capture_status of this CaptureResponse.

        Face capture result status  # noqa: E501

        :return: The capture_status of this CaptureResponse.
        :rtype: List[str]
        """
        return self._capture_status

    @capture_status.setter
    def capture_status(self, capture_status: List[str]):
        """Sets the capture_status of this CaptureResponse.

        Face capture result status  # noqa: E501

        :param capture_status: The capture_status of this CaptureResponse.
        :type capture_status: List[str]
        """
        allowed_values = ["capture_successful", "capture_timedout", "camera_failed", "live_face_detection_failed", "live_face_quality_failed", "liveness_detection_failed"]  # noqa: E501
        if not set(capture_status).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `capture_status` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(capture_status) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._capture_status = capture_status



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401
from typing import List, Dict  # noqa: F401
from yk_utils.models import Model
from yk_utils.models import deserialization


class VerifyRequest(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, capture_time_out: float=10.0, reference_image: str=None, matching_score_threshold: float=0.4, anti_spoofing: bool=True, live_quality_analysis: bool=False, reference_quality_analysis: bool=False):  # noqa: E501
        """VerifyRequest - a model defined in Swagger

        :param capture_time_out: The capture_time_out of this VerifyRequest.  # noqa: E501
        :type capture_time_out: float
        :param reference_image: The reference_image of this VerifyRequest.  # noqa: E501
        :type reference_image: str
        :param matching_score_threshold: The matching_score_threshold of this VerifyRequest.  # noqa: E501
        :type matching_score_threshold: float
        :param anti_spoofing: The anti_spoofing of this VerifyRequest.  # noqa: E501
        :type anti_spoofing: bool
        :param live_quality_analysis: The live_quality_analysis of this VerifyRequest.  # noqa: E501
        :type live_quality_analysis: bool
        :param reference_quality_analysis: The reference_quality_analysis of this VerifyRequest.  # noqa: E501
        :type reference_quality_analysis: bool
        """
        self.swagger_types = {
            'capture_time_out': float,
            'reference_image': str,
            'matching_score_threshold': float,
            'anti_spoofing': bool,
            'live_quality_analysis': bool,
            'reference_quality_analysis': bool
        }

        self.attribute_map = {
            'capture_time_out': 'capture_time_out',
            'reference_image': 'reference_image',
            'matching_score_threshold': 'matching_score_threshold',
            'anti_spoofing': 'anti_spoofing',
            'live_quality_analysis': 'live_quality_analysis',
            'reference_quality_analysis': 'reference_quality_analysis'
        }

        self._capture_time_out = capture_time_out
        self._reference_image = reference_image
        self._matching_score_threshold = matching_score_threshold
        self._anti_spoofing = anti_spoofing
        self._live_quality_analysis = live_quality_analysis
        self._reference_quality_analysis = reference_quality_analysis

    @classmethod
    def from_dict(cls, dikt) -> 'VerifyRequest':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The verify_request of this VerifyRequest.  # noqa: E501
        :rtype: VerifyRequest
        """
        return deserialization.deserialize_model(dikt, cls)

    @property
    def capture_time_out(self) -> float:
        """Gets the capture_time_out of this VerifyRequest.

        Capture timeout in seconds.  # noqa: E501

        :return: The capture_time_out of this VerifyRequest.
        :rtype: float
        """
        return self._capture_time_out

    @capture_time_out.setter
    def capture_time_out(self, capture_time_out: float):
        """Sets the capture_time_out of this VerifyRequest.

        Capture timeout in seconds.  # noqa: E501

        :param capture_time_out: The capture_time_out of this VerifyRequest.
        :type capture_time_out: float
        """

        self._capture_time_out = capture_time_out

    @property
    def reference_image(self) -> str:
        """Gets the reference_image of this VerifyRequest.

        JPG base 64 string reference face image obtained from identification document or any other source.  # noqa: E501

        :return: The reference_image of this VerifyRequest.
        :rtype: str
        """
        return self._reference_image

    @reference_image.setter
    def reference_image(self, reference_image: str):
        """Sets the reference_image of this VerifyRequest.

        JPG base 64 string reference face image obtained from identification document or any other source.  # noqa: E501

        :param reference_image: The reference_image of this VerifyRequest.
        :type reference_image: str
        """

        self._reference_image = reference_image

    @property
    def matching_score_threshold(self) -> float:
        """Gets the matching_score_threshold of this VerifyRequest.

        Matching score threshold used to verify matching between live and reference image.  # noqa: E501

        :return: The matching_score_threshold of this VerifyRequest.
        :rtype: float
        """
        return self._matching_score_threshold

    @matching_score_threshold.setter
    def matching_score_threshold(self, matching_score_threshold: float):
        """Sets the matching_score_threshold of this VerifyRequest.

        Matching score threshold used to verify matching between live and reference image.  # noqa: E501

        :param matching_score_threshold: The matching_score_threshold of this VerifyRequest.
        :type matching_score_threshold: float
        """

        self._matching_score_threshold = matching_score_threshold

    @property
    def anti_spoofing(self) -> bool:
        """Gets the anti_spoofing of this VerifyRequest.

        Activate anti-spoofing detection.  # noqa: E501

        :return: The anti_spoofing of this VerifyRequest.
        :rtype: bool
        """
        return self._anti_spoofing

    @anti_spoofing.setter
    def anti_spoofing(self, anti_spoofing: bool):
        """Sets the anti_spoofing of this VerifyRequest.

        Activate anti-spoofing detection.  # noqa: E501

        :param anti_spoofing: The anti_spoofing of this VerifyRequest.
        :type anti_spoofing: bool
        """

        self._anti_spoofing = anti_spoofing

    @property
    def live_quality_analysis(self) -> bool:
        """Gets the live_quality_analysis of this VerifyRequest.

        Activate ISO/ICAO-19794-5 face quality compliance checks on the live face images.  # noqa: E501

        :return: The live_quality_analysis of this VerifyRequest.
        :rtype: bool
        """
        return self._live_quality_analysis

    @live_quality_analysis.setter
    def live_quality_analysis(self, live_quality_analysis: bool):
        """Sets the live_quality_analysis of this VerifyRequest.

        Activate ISO/ICAO-19794-5 face quality compliance checks on the live face images.  # noqa: E501

        :param live_quality_analysis: The live_quality_analysis of this VerifyRequest.
        :type live_quality_analysis: bool
        """

        self._live_quality_analysis = live_quality_analysis

    @property
    def reference_quality_analysis(self) -> bool:
        """Gets the reference_quality_analysis of this VerifyRequest.

        Activate ISO/ICAO-19794-5 face quality compliance checks on the reference_image.  # noqa: E501

        :return: The reference_quality_analysis of this VerifyRequest.
        :rtype: bool
        """
        return self._reference_quality_analysis

    @reference_quality_analysis.setter
    def reference_quality_analysis(self, reference_quality_analysis: bool):
        """Sets the reference_quality_analysis of this VerifyRequest.

        Activate ISO/ICAO-19794-5 face quality compliance checks on the reference_image.  # noqa: E501

        :param reference_quality_analysis: The reference_quality_analysis of this VerifyRequest.
        :type reference_quality_analysis: bool
        """

        self._reference_quality_analysis = reference_quality_analysis



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401
from typing import List, Dict  # noqa: F401
from yk_utils.models import Model
from yk_utils.models import deserialization


class VerifyResponse(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, matching_score: float=None, verified_image: str=None, verify_status: List[str]=None):  # noqa: E501
        """VerifyResponse - a model defined in Swagger

        :param matching_score: The matching_score of this VerifyResponse.  # noqa: E501
        :type matching_score: float
        :param verified_image: The verified_image of this VerifyResponse.  # noqa: E501
        :type verified_image: str
        :param verify_status: The verify_status of this VerifyResponse.  # noqa: E501
        :type verify_status: List[str]
        """
        self.swagger_types = {
            'matching_score': float,
            'verified_image': str,
            'verify_status': List[str]
        }

        self.attribute_map = {
            'matching_score': 'matching_score',
            'verified_image': 'verified_image',
            'verify_status': 'verify_status'
        }

        self._matching_score = matching_score
        self._verified_image = verified_image
        self._verify_status = verify_status

    @classmethod
    def from_dict(cls, dikt) -> 'VerifyResponse':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The verify_response of this VerifyResponse.  # noqa: E501
        :rtype: VerifyResponse
        """
        return deserialization.deserialize_model(dikt, cls)

    @property
    def matching_score(self) -> float:
        """Gets the matching_score of this VerifyResponse.

        Face matching confidence. Varies between -1 (totally different) to 1 (totally equal).   # noqa: E501

        :return: The matching_score of this VerifyResponse.
        :rtype: float
        """
        return self._matching_score

    @matching_score.setter
    def matching_score(self, matching_score: float):
        """Sets the matching_score of this VerifyResponse.

        Face matching confidence. Varies between -1 (totally different) to 1 (totally equal).   # noqa: E501

        :param matching_score: The matching_score of this VerifyResponse.
        :type matching_score: float
        """

        self._matching_score = matching_score

    @property
    def verified_image(self) -> str:
        """Gets the verified_image of this VerifyResponse.

        JPG base 64 string thumbnail of the live matched image  # noqa: E501

        :return: The verified_image of this VerifyResponse.
        :rtype: str
        """
        return self._verified_image

    @verified_image.setter
    def verified_image(self, verified_image: str):
        """Sets the verified_image of this VerifyResponse.

        JPG base 64 string thumbnail of the live matched image  # noqa: E501

        :param verified_image: The verified_image of this VerifyResponse.
        :type verified_image: str
        """

        self._verified_image = verified_image

    @property
    def verify_status(self) -> List[str]:
        """Gets the verify_status of this VerifyResponse.

        Face verification status  # noqa: E501

        :return: The verify_status of this VerifyResponse.
        :rtype: List[str]
        """
        return self._verify_status

    @verify_status.setter
    def verify_status(self, verify_status: List[str]):
        """Sets the verify_status of this VerifyResponse.

        Face verification status  # noqa: E501

        :param verify_status: The verify_status of this VerifyResponse.
        :type verify_status: List[str]
        """
        allowed_values = ["matching_successful", "matching_failed", "capture_timedout", "camera_failed", "reference_face_detection_failed", "live_face_detection_failed", "liveness_detection_failed", "live_face_quality_failed", "reference_face_quality_failed"]  # noqa: E501
        if not set(verify_status).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `verify_status` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(verify_status) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._verify_status = verify_status



# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401
from typing import List, Dict  # noqa: F401
from yk_utils.models import Model
from yk_utils.models import deserialization


class CaptureRequest(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, capture_time_out: float=10.0, anti_spoofing: bool=True, live_quality_analysis: bool=False):  # noqa: E501
        """CaptureRequest - a model defined in Swagger

        :param capture_time_out: The capture_time_out of this CaptureRequest.  # noqa: E501
        :type capture_time_out: float
        :param anti_spoofing: The anti_spoofing of this CaptureRequest.  # noqa: E501
        :type anti_spoofing: bool
        :param live_quality_analysis: The live_quality_analysis of this CaptureRequest.  # noqa: E501
        :type live_quality_analysis: bool
        """
        self.swagger_types = {
            'capture_time_out': float,
            'anti_spoofing': bool,
            'live_quality_analysis': bool
        }

        self.attribute_map = {
            'capture_time_out': 'capture_time_out',
            'anti_spoofing': 'anti_spoofing',
            'live_quality_analysis': 'live_quality_analysis'
        }

        self._capture_time_out = capture_time_out
        self._anti_spoofing = anti_spoofing
        self._live_quality_analysis = live_quality_analysis

    @classmethod
    def from_dict(cls, dikt) -> 'CaptureRequest':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The capture_request of this CaptureRequest.  # noqa: E501
        :rtype: CaptureRequest
        """
        return deserialization.deserialize_model(dikt, cls)

    @property
    def capture_time_out(self) -> float:
        """Gets the capture_time_out of this CaptureRequest.

        Capture timeout in seconds.  # noqa: E501

        :return: The capture_time_out of this CaptureRequest.
        :rtype: float
        """
        return self._capture_time_out

    @capture_time_out.setter
    def capture_time_out(self, capture_time_out: float):
        """Sets the capture_time_out of this CaptureRequest.

        Capture timeout in seconds.  # noqa: E501

        :param capture_time_out: The capture_time_out of this CaptureRequest.
        :type capture_time_out: float
        """
        if capture_time_out is not None and capture_time_out < 0:  # noqa: E501
            raise ValueError("Invalid value for `capture_time_out`, must be a value greater than or equal to `0`")  # noqa: E501

        self._capture_time_out = capture_time_out

    @property
    def anti_spoofing(self) -> bool:
        """Gets the anti_spoofing of this CaptureRequest.

        Activate anti-spoofing detection.  # noqa: E501

        :return: The anti_spoofing of this CaptureRequest.
        :rtype: bool
        """
        return self._anti_spoofing

    @anti_spoofing.setter
    def anti_spoofing(self, anti_spoofing: bool):
        """Sets the anti_spoofing of this CaptureRequest.

        Activate anti-spoofing detection.  # noqa: E501

        :param anti_spoofing: The anti_spoofing of this CaptureRequest.
        :type anti_spoofing: bool
        """

        self._anti_spoofing = anti_spoofing

    @property
    def live_quality_analysis(self) -> bool:
        """Gets the live_quality_analysis of this CaptureRequest.

        Activate ISO/ICAO-19794-5 face quality compliance checks on the live face images.  # noqa: E501

        :return: The live_quality_analysis of this CaptureRequest.
        :rtype: bool
        """
        return self._live_quality_analysis

    @live_quality_analysis.setter
    def live_quality_analysis(self, live_quality_analysis: bool):
        """Sets the live_quality_analysis of this CaptureRequest.

        Activate ISO/ICAO-19794-5 face quality compliance checks on the live face images.  # noqa: E501

        :param live_quality_analysis: The live_quality_analysis of this CaptureRequest.
        :type live_quality_analysis: bool
        """

        self._live_quality_analysis = live_quality_analysis



from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="yk_bit",
    version="1.1.0",
    description="Python SDK for the YooniK BiometricInThings API.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="YooniK",
    author_email="tech@yoonik.me",
    url="https://github.com/dev-yoonik/YK-BiT-SDK-Python",
    license='MIT',
    packages=[
        "yk_bit",
        "yk_bit.models"
    ],
    install_requires=[
        "six",
        "requests",
        "setuptools",
        "yk-utils>=0.2.0,<1"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
